@@ -8,7 +8,7 @@ from loguru import logger
 from tqatest.ml.libs import annhub
 
 MODEL_NAME = "TrainedModel_c++.ann"
-MODEL_PATH = "ml/model"
+MODEL_PATH = "tqatest/ml/model"
 MODEL_ID = 5122020
 
 class MachineLearningModel(object):
